@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['type_0',['type',['../a00694.html#a099d97275eaf0055a5870379257496bc',1,'rtl::libreoffice_internal::CharPtrDetector&lt; char *, T &gt;::Type'],['../a00702.html#a42a8350585ca497d33c2d2ccf4addd15',1,'rtl::libreoffice_internal::NonConstCharArrayDetector&lt; char[N], T &gt;::Type'],['../a00710.html#a28efe8c0d1cbf12531ba41c71923392c',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;::Type'],['../a00718.html#a74ff5a7199580150e377a53aecac91e5',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; const sal_Unicode *, T &gt;::Type'],['../a00722.html#aa3d4b27ff0bc4723c1fa792cc8068736',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; sal_Unicode *, T &gt;::Type'],['../a00730.html#ac656c24e3f3cae795b3b993797be1ccb',1,'rtl::libreoffice_internal::Enable&lt; T, true &gt;::Type'],['../a00690.html#abe914ff74f7219275474ec5a791eddc4',1,'rtl::libreoffice_internal::CharPtrDetector&lt; const char *, T &gt;::Type']]],
+  ['type_0',['Type',['../a00690.html#ab5f786d4f146579ea4f0dee29706d118',1,'rtl::libreoffice_internal::CharPtrDetector&lt; const char *, T &gt;::Type'],['../a00694.html#ab37d4a2f49f310faae32e983cb2c66b0',1,'rtl::libreoffice_internal::CharPtrDetector&lt; char *, T &gt;::Type'],['../a00702.html#ada81bc11618c230252403b28b540c946',1,'rtl::libreoffice_internal::NonConstCharArrayDetector&lt; char[N], T &gt;::Type'],['../a00710.html#a93c2f352a7bd00c0e73b84b6e79b177e',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;::Type'],['../a00718.html#a6ec1447582a6a15cf97de5197af8fa46',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; const sal_Unicode *, T &gt;::Type'],['../a00722.html#af506e971b2de71313a9a2c9f96ec1f29',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; sal_Unicode *, T &gt;::Type'],['../a00730.html#a35aa3c09eb3779ed1294ec181f12cec6',1,'rtl::libreoffice_internal::Enable&lt; T, true &gt;::Type']]],
   ['typelib_5fcompoundmember_5finit_1',['typelib_CompoundMember_Init',['../a00251.html#aa5c7b9b7196d0a4ba0a4e22ac94d4dfb',1,'typedescription.h']]],
   ['typelib_5fcompoundtypedescription_2',['typelib_CompoundTypeDescription',['../a00251.html#a35f7c218b18f14a3d745a6bd8ff7cee0',1,'typedescription.h']]],
   ['typelib_5fenumtypedescription_3',['typelib_EnumTypeDescription',['../a00251.html#ad24e07aaa537cbed3e6eaa30c4a971bb',1,'typedescription.h']]],
@@ -8,14 +8,14 @@ var searchData=
   ['typelib_5finterfaceattributetypedescription_5',['typelib_InterfaceAttributeTypeDescription',['../a00251.html#ab1c8babceb2ec36c93ea1a7e70b12e60',1,'typedescription.h']]],
   ['typelib_5finterfacemembertypedescription_6',['typelib_InterfaceMemberTypeDescription',['../a00251.html#aa370ca1e9cfcd6c0cd0d25575ed9e24a',1,'typedescription.h']]],
   ['typelib_5finterfacemethodtypedescription_7',['typelib_InterfaceMethodTypeDescription',['../a00251.html#afefdbbdf596c4d27895b40838d5b13b8',1,'typedescription.h']]],
-  ['typelib_5finterfacetypedescription_8',['typelib_interfacetypedescription',['../a00251.html#a1fda682c9e149332b5e28f79b0ee5ac3',1,'typelib_InterfaceTypeDescription:&#160;typedescription.h'],['../a02525.html#a135ee80e11475025c4d7b672daf5ec80',1,'typelib_InterfaceTypeDescription:&#160;mapping.hxx']]],
+  ['typelib_5finterfacetypedescription_8',['typelib_InterfaceTypeDescription',['../a00251.html#a1fda682c9e149332b5e28f79b0ee5ac3',1,'typelib_InterfaceTypeDescription:&#160;typedescription.h'],['../a02525.html#a135ee80e11475025c4d7b672daf5ec80',1,'typelib_InterfaceTypeDescription:&#160;mapping.hxx']]],
   ['typelib_5fmethodparameter_9',['typelib_MethodParameter',['../a00251.html#a86e083c98ae7a86db83ba79f1d8b13ac',1,'typedescription.h']]],
   ['typelib_5fparameter_5finit_10',['typelib_Parameter_Init',['../a00251.html#aa91004d7f20e760b21ccfe3348f65ca6',1,'typedescription.h']]],
   ['typelib_5fstructmember_5finit_11',['typelib_StructMember_Init',['../a00251.html#a61702b937b233f116f499521fee60833',1,'typedescription.h']]],
   ['typelib_5fstructtypedescription_12',['typelib_StructTypeDescription',['../a00251.html#abad336cafbadcc6f3dc634ebb3f4f793',1,'typedescription.h']]],
   ['typelib_5ftypeclass_13',['typelib_TypeClass',['../a00248.html#afee0e779c2ad65be145f9737d280003e',1,'typeclass.h']]],
-  ['typelib_5ftypedescription_14',['typelib_typedescription',['../a00251.html#a1faf233e60aae7be45782bc6fbe4bb3a',1,'typelib_TypeDescription:&#160;typedescription.h'],['../a02525.html#a41cd5e3ff05a0036f6eafbab381bab37',1,'typelib_TypeDescription:&#160;mapping.hxx']]],
+  ['typelib_5ftypedescription_14',['typelib_TypeDescription',['../a00251.html#a1faf233e60aae7be45782bc6fbe4bb3a',1,'typelib_TypeDescription:&#160;typedescription.h'],['../a02525.html#a41cd5e3ff05a0036f6eafbab381bab37',1,'typelib_TypeDescription:&#160;mapping.hxx']]],
   ['typelib_5ftypedescription_5fcallback_15',['typelib_typedescription_Callback',['../a00251.html#a9f387dec51ab9dc1992766b12c6f87cd',1,'typedescription.h']]],
-  ['typelib_5ftypedescriptionreference_16',['typelib_typedescriptionreference',['../a00251.html#a9039ba205d09d7b1c4d463d7eb53e802',1,'typelib_TypeDescriptionReference:&#160;typedescription.h'],['../a00494.html#ab77600bfa8495f8d8e5fd62682f9d643',1,'typelib_TypeDescriptionReference:&#160;genfunc.h']]],
-  ['typelib_5fuik_17',['typelib_Uik',['../a00254.html#ab25a93b006df5a5d609236c207a8a9f7',1,'uik.h']]]
+  ['typelib_5ftypedescriptionreference_16',['typelib_TypeDescriptionReference',['../a00251.html#a9039ba205d09d7b1c4d463d7eb53e802',1,'typelib_TypeDescriptionReference:&#160;typedescription.h'],['../a00494.html#ab77600bfa8495f8d8e5fd62682f9d643',1,'typelib_TypeDescriptionReference:&#160;genfunc.h']]],
+  ['typelib_5fuik_17',['typelib_Uik',['../a00257.html#ab25a93b006df5a5d609236c207a8a9f7',1,'uik.h']]]
 ];
